@@ -2,7 +2,7 @@ package Lingua::TokenParse;
 
 use strict;
 use vars qw($VERSION);
-$VERSION = '0.07.1';
+$VERSION = '0.08.1';
 
 # NOTE: The {{{ and }}} things are "editor code fold markers".  They
 # are merely a convenience for people who don't care to scroll through
@@ -114,15 +114,16 @@ sub build_parts {  # {{{
 
 sub build_combinations {  # {{{
     my ($self, $i) = @_;
-    $i = 0 unless defined $i;
+    $i    = 0 unless defined $i;
     $prev = 0 unless defined $prev;
 
     for (@{ $self->parts->[$i] }) {
         # Find the end-position of the stem.
         my $n = $i + length;
 
-        # XXX Ugly mystery-hack:
-        # Yank-off the last two stems found, if we are at an "overlap point".
+        # XXX This is an ugly mystery-hack:
+        # Yank-off the last two stems found, if we are at an
+        # "overlap point".
         splice @new, -2 if $prev > $i;
 
 #print "$_ - i: $i, n: $n, prev: $prev, new: ". @new ."\n";
@@ -131,7 +132,8 @@ sub build_combinations {  # {{{
 
         splice @new, @new, $n, $_;
 
-        push @{ $self->combinations }, join '.', @new if $n == length ($self->word);
+        push @{ $self->combinations }, join '.', @new
+            if $n == length ($self->word);
 
         $self->build_combinations($n);
     }
@@ -267,6 +269,7 @@ sub _hyphenate {  # {{{
 
 sub output_knowns {  # {{{
     my $self = shift;
+    my @out = ();
 
     for (reverse
              sort { $self->knowns->{$a} <=> $self->knowns->{$b} }
@@ -279,8 +282,12 @@ sub output_knowns {  # {{{
                     ? $self->definitions->{$chunk}
                     : '?';
         }
-        printf qq/%s: %0.2f\n"%s"\n\n/, $_, $self->knowns->{$_}, join '; ', @definition;
+
+        push @out, sprintf qq/%s: %0.2f\n"%s"/,
+            $_, $self->knowns->{$_}, join '; ', @definition;
     }
+
+    return wantarray ? @out : join "\n\n", @out;
 }  # }}}
 
 1;
@@ -298,10 +305,10 @@ Lingua::TokenParse - Parse a word into scored, fragment combinations
   my %lexicon;
   @lexicon{qw(ti art ion)} = qw(foo bar baz);
   my $obj = Lingua::TokenParse->new(
-      word => $word,
+      word    => $word,
       lexicon => \%lexicon,
   );
-  $obj->output_knowns;
+  print scalar $obj->output_knowns;
 
   # Okay.  Now, let's parse a new word.
   $obj->word('metaphysical');
@@ -313,7 +320,7 @@ Lingua::TokenParse - Parse a word into scored, fragment combinations
       '-al'   => 'relating to, characterized by',
   });
   $obj->parse;
-  $obj->output_knowns;
+  my @knowns = $obj->output_knowns;
 
 =head1 ABSTRACT
 
@@ -332,12 +339,11 @@ represents a measure of familiarity.
 Currently, this familiarity mesasure is a simple ratio of known to 
 unknown parts.
 
-* Please note that your lexicon absolutely must have definitions for 
-each entry in order to have the current trim_knowns() method do the 
-right thing.  Yes, this will be fixed in a coming version...  : )
+Note that the lexicon must have definitions for each entry, in order 
+to have the current trim_knowns() method do the right thing.
 
-* Please check out the sample code in the distribution's eg/ 
-directory for exciting examples of how this module can be used.
+* Check out the sample code in the distribution's eg/ directory for 
+examples of how this module can be used.
 
 =head1 METHODS
 
@@ -353,15 +359,6 @@ Return a new Lingua::TokenParse object.
 This method will automatically call the partition methods (detailed 
 below) if a word and lexicon are provided.
 
-=head2 _reset_parse()
-
-  $obj->_reset_parse();
-
-Reset the lists used to parse a word into fragment combinations.
-
-This method is automatically called prior to reparsing a new word in 
-the same session and should never need to be called explicitly.
-
 =head2 parse()
 
   $obj->parse();
@@ -394,10 +391,9 @@ Compute the familiar word part combinations, accessed via the knowns()
 method.
 
 This method handles word parts containing prefix and suffix hyphens,
-which are found in the dict.org sever (with web1913 database).  These
-hyphens actually "encode" information about what is a syntactically 
-legal word combination.  Which can be used to score (or just throw 
-out bogus combinations).
+which encode information about what is a syntactically illegal word 
+combination.  This can be used to score (or throw out bogus 
+combinations).
 
 =head2 build_definitions()
 
@@ -415,10 +411,17 @@ unknown fragments concatinated.
 
 =head2 output_knowns()
 
-  $obj->output_knowns();
+  print scalar $obj->output_knowns();
 
-Convenience method to output the familiar word part combinations with
-their familiarity scores rounded to two decimals.
+  @knowns = $obj->output_knowns();
+
+Convenience method to return the familiar word part combinations with
+their familiarity scores (rounded to two decimals) and semicolon 
+separated, fragment definitions in either scalar or array context.
+
+In scalar context, a single, newline separated string is returned.
+In array context, each of these combinations is a separate entry in 
+an array.
 
 =head1 ACCESSORS
 
@@ -450,7 +453,7 @@ The array reference of word partitions.
 Note that this method is only useful for fetching, since the parts 
 are computed by the build_parts() method.
 
-=head2 combinations()
+=head2 combinations();
 
   $combinations = $obj->combinations();
 
@@ -487,14 +490,15 @@ None
 This module uses some clunky, inefficient algorithms.  For instance,
 a 50 letter word (like a medical term) just might take until the end
 of time to parse and possibly longer.  Please write to me with 
-improvements!
+ much needed improvements!
 
 =head1 TO DO
 
 Calculate familiarity with more granularity.  Possibly with a
 multidimensional measure.
 
-Handle the build_combinations method and related globals correctly.
+Handle the build_combinations method and related globals better, 
+somehow.
 
 Compute the time required for a given parse.
 
